@@ -6,12 +6,15 @@ class FileFormat(Enum):
     HDF5_ZNLOS = 1
     HDF5_NLOS_DIRAC = 2
     HDF5_TAL = 3
+    MAT_PHASOR_FIELDS = 4
 
 
 class HFormat(Enum):
     UNKNOWN = 0
     T_Sx_Sy = 1  # confocal or not
     T_Lx_Ly_Sx_Sy = 2
+    T_Si = 3  # confocal or not
+    T_Si_Li = 4
 
 
 class GridFormat(Enum):
@@ -24,6 +27,7 @@ class VolumeFormat(Enum):
     UNKNOWN = 0
     N_3 = 1
     X_Y_Z_3 = 2
+    X_Y_3 = 3
 
 
 class CameraSystem(Enum):
